topics.Interest (Interest) — amici1

# `topics.Interest` (Interest)

Interest(id, owner_type, owner_id, topic, remark, partner)

Master tables : topics.AllInterests (Interests), topics.Interests (Interests)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Topic (topic) : See `<django.db.models.fields.related.ForeignKey: topic>`.

- Remark (remark) : See `<lino.core.fields.RichTextField: remark>`.

- Partner (partner) : See `<django.db.models.fields.related.ForeignKey: partner>`.

- Name (name_column) : See `lino_xl.lib.topics.models.Interest.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.topics.models.Interest.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.topics.models.Interest.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
topic | Topic |
remark | Remark |
partner | Partner |
owner | Controlled by |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |